@@ -67,7 +67,7 @@ class Recipe:
             self.patch_binaries(ws_locations)
 
             # Install extra scripts
-            self.install_scripts(ws_locations)
+            self.install_scripts()
 
             # Add zcml files to package-includes
             self.build_package_includes()
@@ -132,10 +132,16 @@ class Recipe:
             verbose_security = options.get('verbose-security', 'off')
             if verbose_security == 'on':
                 security_implementation = 'python'
+            port_base = options.get('port-base', '')
+            if port_base:
+                port_base = 'port-base %s' % port_base
             http_address = options.get('http-address', '8080')
             effective_user = options.get('effective-user', '')
             if effective_user:
                effective_user = 'effective-user %s' % effective_user 
+            ip_address = options.get('ip-address', '')
+            if ip_address:
+                ip_address = 'ip-address %s' % ip_address
             
             zope_conf_additional = options.get('zope-conf-additional', '')
         
@@ -147,12 +153,20 @@ class Recipe:
             if not os.path.exists(event_log_dir):
                 os.makedirs(event_log_dir)
             
+            event_log_level = options.get('event-log-level', 'INFO')
+            
             z_log_name = options.get('z-log', os.path.sep.join(('var', 'log', self.name + '-Z2.log',)))
             z_log = os.path.join(base_dir, z_log_name)
             z_log_dir = os.path.dirname(z_log)
             if not os.path.exists(z_log_dir):
                 os.makedirs(z_log_dir)
             
+            z_log_level = options.get('z2-log-level', 'WARN')
+            
+            default_zpublisher_encoding = options.get('default-zpublisher-encoding', '')
+            if default_zpublisher_encoding:
+                default_zpublisher_encoding = 'default-zpublisher-encoding %s' % default_zpublisher_encoding
+            
             file_storage = options.get('file-storage', os.path.sep.join(('var', 'filestorage', 'Data.fs',)))
             file_storage = os.path.join(base_dir, file_storage)
             file_storage_dir = os.path.dirname(file_storage)
@@ -163,17 +177,21 @@ class Recipe:
             blob_storage = options.get('blob-storage', None)
             if blob_storage:
                 blob_storage = os.path.join(base_dir, blob_storage)
-                blob_storage_dir = os.path.dirname(blob_storage)
-                if not os.path.exists(blob_storage_dir):
-                    os.makedirs(blob_storage_dir)
+                if not os.path.exists(blob_storage):
+                    os.makedirs(blob_storage)
                 storage_snippet = blob_storage_template % (blob_storage, file_storage)
+                
+            zserver_threads = options.get('zserver-threads', '')
+            if zserver_threads:
+                zserver_threads = 'zserver-threads %s' % zserver_threads
 
             zeo_client = options.get('zeo-client', '')
             zeo_address = options.get('zeo-address', '8100')
         
-            zodb_cache_size = options.get('zodb-cache-size', '2000')
+            zodb_cache_size = options.get('zodb-cache-size', '5000')
             zeo_client_cache_size = options.get('zeo-client-cache-size', '30MB')
-        
+            zeo_storage = options.get('zeo-storage', '1')
+
             if zeo_client.lower() in ('yes', 'true', 'on', '1'):
                 template = zeo_conf_template
             else:
@@ -185,13 +203,20 @@ class Recipe:
                                         security_implementation = security_implementation,
                                         verbose_security = verbose_security,
                                         effective_user = effective_user,
+                                        ip_address = ip_address,
                                         event_log = event_log,
+                                        event_log_level = event_log_level,
                                         z_log = z_log,
-                                        storage_snippet = storage_snippet,
+                                        z_log_level = z_log_level,
+                                        default_zpublisher_encoding = default_zpublisher_encoding,
+                                        storage_snippet = storage_snippet.strip(),
+                                        port_base = port_base,
                                         http_address = http_address,
                                         zeo_address = zeo_address,
+                                        zserver_threads = zserver_threads,
                                         zodb_cache_size = zodb_cache_size,
                                         zeo_client_cache_size = zeo_client_cache_size,
+                                        zeo_storage = zeo_storage,
                                         zope_conf_additional = zope_conf_additional,)
         
         zope_conf_path = os.path.join(location, 'etc', 'zope.conf')
@@ -207,7 +232,7 @@ class Recipe:
             script = open(script_path).read()
             script = script.replace(
                 '$SOFTWARE_HOME:$PYTHONPATH',
-                '$SOFTWARE_HOME:'+path+':$PYTHONPATH'
+                path+':$SOFTWARE_HOME:$PYTHONPATH'
                 )
             f = open(script_path, 'w')
             f.write(script)
@@ -223,7 +248,7 @@ class Recipe:
             script = '\n'.join(lines)
             script = script.replace(
                 'PYTHONPATH=%SOFTWARE_HOME%',
-                'PYTHONPATH=%SOFTWARE_HOME%;'+path+';%PYTHONPATH%'
+                'PYTHONPATH='+path+';%SOFTWARE_HOME%;%PYTHONPATH%'
                 )
             f = open(script_path, 'w')
             f.write(script)
@@ -270,7 +295,7 @@ if __name__ == '__main__':
         f.write(script)
         f.close()
 
-    def install_scripts(self, ws_locations):
+    def install_scripts(self):
         options = self.options
         location = options['location']
         
@@ -280,7 +305,7 @@ if __name__ == '__main__':
         extra_paths = [os.path.join(location),
                        os.path.join(options['zope2-location'], 'lib', 'python')
                       ]
-        extra_paths.extend(ws_locations)
+        extra_paths.extend(options.get('extra-paths', '').split())
         
         requirements, ws = self.egg.working_set(['plone.recipe.zope2instance'])
 
@@ -377,18 +402,18 @@ if __name__ == '__main__':
                     )
 
 # Storage snippets for zope.conf template
-file_storage_template="""\
-<filestorage>
+file_storage_template="""
+    <filestorage>
       path %s
-    </filestorage>\
+    </filestorage>
 """
-blob_storage_template="""\
-<blobstorage>
+blob_storage_template="""
+    <blobstorage>
       blob-dir %s
       <filestorage>
         path %s
       </filestorage>
-    </blobstorage>\
+    </blobstorage>
 """
 
 # The template used to build zope.conf
@@ -398,10 +423,14 @@ instancehome %(instance_home)s
 debug-mode %(debug_mode)s
 security-policy-implementation %(security_implementation)s
 verbose-security %(verbose_security)s
+%(default_zpublisher_encoding)s
+%(port_base)s
 %(effective_user)s
+%(ip_address)s
+%(zserver_threads)s
 
 <eventlog>
-  level info
+  level %(event_log_level)s
   <logfile>
     path %(event_log)s
     level info
@@ -409,7 +438,7 @@ verbose-security %(verbose_security)s
 </eventlog>
 
 <logger access>
-  level WARN
+  level %(z_log_level)s
   <logfile>
     path %(z_log)s
     format %%(message)s
@@ -449,10 +478,14 @@ instancehome %(instance_home)s
 debug-mode %(debug_mode)s
 security-policy-implementation %(security_implementation)s
 verbose-security %(verbose_security)s
+%(default_zpublisher_encoding)s
+%(port_base)s
 %(effective_user)s
+%(ip_address)s
+%(zserver_threads)s
 
 <eventlog>
-  level info
+  level %(event_log_level)s
   <logfile>
     path %(event_log)s
     level info
@@ -460,7 +493,7 @@ verbose-security %(verbose_security)s
 </eventlog>
 
 <logger access>
-  level WARN
+  level %(z_log_level)s
   <logfile>
     path %(z_log)s
     format %%(message)s
@@ -480,7 +513,7 @@ verbose-security %(verbose_security)s
   cache-size %(zodb_cache_size)s
   <zeoclient>
     server %(zeo_address)s
-    storage 1
+    storage %(zeo_storage)s
     name zeostorage
     var %(instance_home)s/var
     cache-size %(zeo_client_cache_size)s
