@@ -28,8 +28,14 @@ action "help" to find out about available actions.
 """
 
 import os, sys
-from Zope2.Startup import zopectl
-from Zope2.Startup import handlers
+try:
+    # Zope 2.8+
+    from Zope2.Startup import zopectl
+    from Zope2.Startup import handlers
+except ImportError:
+    # Zope 2.7 (and below)
+    from Zope.Startup import zopectl
+    from Zope.Startup import handlers    
 
 WIN32 = False
 if sys.platform[:3].lower() == "win":
@@ -91,6 +97,13 @@ class AdjustedZopeCmd(zopectl.ZopeCmd):
         # automatically with all configured products and eggs.
         args = filter(None, arg.split(' '))
 
+        # Disable deprecation warnings if desired
+        for nowarn in '--nowarn', '--nowarning':
+            if nowarn in args:
+                args.remove(nowarn)
+                from warnings import filterwarnings
+                filterwarnings("ignore", ".*", DeprecationWarning)
+
         defaults = []
         softwarehome = self.options.configroot.softwarehome
 
